# RAPID - Robustness Analysis Producing Intelligent Decisions
The RAPID software package enables the generic guidance framework introduced in McPhail et al. (soon to be published) (see reference below) to be implemented in a user-friendly and consistent manner, including functionality to guide the user through the process of creating a custom robustness metric.
McPhail, C., Maier, H.R., Westra, S., van der Linden, L., Kwakkel, J.H. (to be published). Guidance framework and software for understanding and achieving system robustness.

## Getting started
### Prerequisites
Python 3.x

### Installing
This software package can be installed from PyPI
```
pip install rapidrobustness
```

## Authors
* **Cameron McPhail** - *Initial development of package*

## License
This project is licensed under the MIT license - see the [LICENSE](LICENSE) file for details.

## Acknowledgements
* Supervisors and co-authors who contributed to Cameron McPhail's PhD (and therefore the concepts underpinning this package): Holger Maier, Seth Westra, and Leon van der Linden.
* Co-authors from several papers which were created prior to this package: Andrea Casttelletti, Matteo Giuliani, and Jan Kwakkel.
* Inspiration for this package was drawn from the [EMA Workbench](https://github.com/quaquel/EMAworkbench), created by Jan Kwakkel.